==> QuickAMS-1.1.0-sources.jar: cn/schoolwow/ams/flow/dispatcher/OperationDispatcherFlow.java <==
package cn.schoolwow.ams.flow.dispatcher;

import cn.schoolwow.ams.listener.AMSOperation;
import cn.schoolwow.quickflow.domain.FlowContext;
import cn.schoolwow.quickflow.flow.BusinessFlow;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Collection;

@Service
public class OperationDispatcherFlow implements BusinessFlow {
    @Override
    public void executeBusinessFlow(FlowContext flowContext) throws Exception {
        String projectName = (String) flowContext.checkData("projectName");
        String daoName = (String) flowContext.checkData("daoName");
        String tableName = (String) flowContext.checkData("tableName");
        String methodName = (String) flowContext.checkData("methodName");
        JSONObject requestBody = (JSONObject) flowContext.getData("requestBody");
        Collection<AMSOperation> amsOperationList = (Collection<AMSOperation>) flowContext.getData("amsOperationList");

        if(null==amsOperationList){
            throw new IllegalArgumentException("不支持的操作!dao:"+daoName+",表名:"+tableName+",方法名:"+methodName);
        }
        for(AMSOperation amsOperation:amsOperationList){
            if(!daoName.equalsIgnoreCase(amsOperation.daoName())){
                continue;
            }
            if(!tableName.equalsIgnoreCase(amsOperation.tableName())){
                continue;
            }
            if(StringUtils.isNoneBlank(amsOperation.methodName())&&!methodName.equalsIgnoreCase(amsOperation.methodName())){
                continue;
            }
            JSONObject response = amsOperation.handle(methodName, requestBody);
            flowContext.putData("response", response);
            return;
        }
        throw new IllegalArgumentException("不支持的操作!项目名:"+projectName+",数据库名:"+daoName+",表名:"+tableName+",方法名:"+methodName);
    }

    @Override
    public String name() {
        return "ams操作分发";
    }
}

==> QuickAMS-1.1.14-sources.jar: cn/schoolwow/ams/flow/dispatcher/OperationDispatcherFlow.java <==
package cn.schoolwow.ams.flow.dispatcher;

import cn.schoolwow.ams.listener.AMSOperation;
import cn.schoolwow.quickflow.domain.FlowContext;
import cn.schoolwow.quickflow.flow.BusinessFlow;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.Validate;
import org.springframework.stereotype.Service;

import java.util.Collection;

@Service
public class OperationDispatcherFlow implements BusinessFlow {
    @Override
    public void executeBusinessFlow(FlowContext flowContext) throws Exception {
        String projectName = (String) flowContext.checkData("projectName");
        String daoName = (String) flowContext.checkData("daoName");
        String tableName = (String) flowContext.checkData("tableName");
        String methodName = (String) flowContext.checkData("methodName");
        JSONObject requestBody = (JSONObject) flowContext.getData("requestBody");
        Collection<AMSOperation> amsOperationList = (Collection<AMSOperation>) flowContext.getData("amsOperationList");

        if(null==amsOperationList){
            throw new IllegalArgumentException("不支持的操作!dao:"+daoName+",表名:"+tableName+",方法名:"+methodName);
        }
        for(AMSOperation amsOperation:amsOperationList){
            if(!daoName.equalsIgnoreCase(amsOperation.daoName())){
                continue;
            }
            if(!tableName.equalsIgnoreCase(amsOperation.tableName())){
                continue;
            }
            if(StringUtils.isNoneBlank(amsOperation.methodName())&&!methodName.equalsIgnoreCase(amsOperation.methodName())){
                continue;
            }
            String[] fieldNameList = amsOperation.fieldNameList();
            if(null!=fieldNameList){
                if(amsOperation.methodName().startsWith("multiple")){
                    if(fieldNameList.length==1){
                        Validate.isTrue(requestBody.containsKey(fieldNameList[0]+"List"), fieldNameList[0]+"字段不能为空");
                        Validate.notEmpty(requestBody.getJSONArray(fieldNameList[0]+"List"), "字段不能为空");
                    }else{
                        Validate.isTrue(requestBody.containsKey("list"), "参数列表不能为空");
                        Validate.notEmpty(requestBody.getJSONArray("list"), "参数列表不能为空");
                    }
                }else{
                    for(String fieldName:fieldNameList){
                        Validate.isTrue(requestBody.containsKey(fieldName), fieldName+"参数不能为空");
                    }
                }
            }
            JSONObject response = amsOperation.handle(methodName, requestBody);
            flowContext.putData("response", response);
            return;
        }
        throw new IllegalArgumentException("不支持的操作!项目名:"+projectName+",数据库名:"+daoName+",表名:"+tableName+",方法名:"+methodName);
    }

    @Override
    public String name() {
        return "ams操作分发";
    }
}
